import createCache from '@emotion/cache';
import { CacheProvider } from '@emotion/react';
import createTheme from '@mui/material/styles/createTheme';
import ThemeProvider from '@mui/material/styles/ThemeProvider';
import React from 'react';
import ReactDOM from 'react-dom/client';
import App from './App';

// 注入应用容器
const container = document.createElement('div');
container.id = 'monkey';
container.style.all = 'initial';
document.body.appendChild(container);

// 创建 shadow DOM
const shadowContainer = container.attachShadow({ mode: 'closed' });

// 将应用添加到 shadow DOM 中
const app = document.createElement('div');
shadowContainer.appendChild(app);

// 将 emotion 样式添加到 shadow DOM 中
const emotionRoot = document.createElement('style');
shadowContainer.appendChild(emotionRoot);

const cache = createCache({
  key: 'css',
  prepend: true,
  container: emotionRoot,
});

// 获取浏览器的字体大小
const { fontSize } = window.getComputedStyle(document.documentElement);
const htmlFontSize = parseFloat(fontSize);

const theme = createTheme({
  components: {
    MuiPopover: {
      defaultProps: {
        container: app,
      },
    },
    MuiPopper: {
      defaultProps: {
        container: app,
      },
    },
    MuiModal: {
      defaultProps: {
        container: app,
      },
    },
  },
  typography: {
    htmlFontSize,
  },
});

ReactDOM.createRoot(app).render(
  <React.StrictMode>
    <CacheProvider value={cache}>
      <ThemeProvider theme={theme}>
        <App />
      </ThemeProvider>
    </CacheProvider>
  </React.StrictMode>
);
